<?php
/**
 * LDAP connection URI
 * You can use any address syntax supported by your LDAP library.
 * Connection can be secured with ldaps or ldapi URIs.
 * @param string $ldap_server
 */
$ldap_server = 'localhost';

/**
 * Controls LDAP bind protocol version.
 * PHP and plugin defaults to v2 bind. Some LDAP servers (OpenLDAP v.2.1+)
 * disable v2 bind by default.
 * @param integer $ldap_protocol_version
 * @since 1.9
 */
$ldap_protocol_version = 2;

/**
 * Sets field used to store user's password.
 * Defaults to 'userpassword'
 * @param string $ldap_password_field
 */
$ldap_password_field = 'userpassword';

/**
 * Sets field used to store username.
 * Defaults to 'uid'
 * @param string $ldap_user_field
 */
$ldap_user_field = 'uid';

/**
 * put the ldap base dn of your server here
 * @param string $ldap_basedn
 */
$ldap_base_dn = 'o=gouv,c=fr';

// we first bind to retreive the users full DN for the account by looking up 
// the attribute defined above in $ldap_user_field. The account used to do the 
// initial lookup is defined in $query_dn and $query_pw.  If these vars are
// blank or unset we bind anonymously. 

// NOTE: You only need to set values here if you have disabled anonymous queries.
$query_dn = '';
$query_pw = '';

/**
 * After getting the users DN, we will bind as that DN to verify the password.
 * Of course, if the dn is not permitted to bind, this fails.  To skip the password
 * check via ldap-bind, define $no_bind_as_user
 * @param boolean $no_bind_as_user
 */
$no_bind_as_user = false;

// We normally change the users password while bound with their dn.
// Of course, if you have'nt permitted the user write access to the password
// field, this won't work.  You can either fix the ACL in slapd.conf or the 
// equivelent in your LDAP server, or do the insecure thing and bind as the
// manager.

// USE THIS IF YOU DON'T CARE ABOUT SECURITY.
$ldap_bind_as_manager = false;
$ldap_manager_dn="cn=manager,$ldap_base_dn";
$ldap_manager_pw='secret';

//if you're also using LDAP to authenticate samba users, we can sync the samba passwords too
$change_smb=false;
$smb_passwd='/usr/bin/smbpasswd';
// NOTE: set this to the NETBIOS name of your samba host if it is NOT localhost
$smb_host='';

// and maybe you are using samba/ldap authentication, in this case you
// you will need mkntpwd in order to generate the nt/lm password.
// http://www.samba.org/cgi-bin/cvsweb/samba/examples/LDAP/smbldap-tools/mkntpwd/
$change_ldapsmb=true;
$mkntpwd='/usr/bin/mkntpwd';
// NOTE: only for samba-2.2.x or samba-3.x.x in 2.2.x compat mode
//$ldapsmb_lmpassword='lmpassword';
//$ldapsmb_ntpassword='ntpassword';

// NOTE: only for samba-3.x.x (using the new samba.schema)
$ldapsmb_lmpassword='sambalmpassword';
$ldapsmb_ntpassword='sambantpassword';

/**
 * Controls display of debug information
 * @param boolean $debug
 */
$debug = false;

/**
 * Local variables:
 * mode: php
 * End:
 * vim: syntax=php et ts=4
 */
